/*
 *   (C) Copyright IBM Corp. 2001, 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Module: mdregmgr
 * File: linear_mgr.h
 */

#ifndef _LINEAR_MGR_H_
#define _LINEAR_MGR_H_

//Create Option
#define LINEAR_CREATE_OPT_COUNT         1

#define LINEAR_CREATE_OPT_SB1_INDEX	0
#define LINEAR_CREATE_OPT_SB1_NAME	"ver1_superblock"

// Plug-in functions : none
#define MD_LINEAR_FUNCTION_COUNT		0

// Linear region manager flags
#define MD_LINEAR_CONFIG_CHANGE_PENDING		(1<<0)



#endif

